@@ -1,4 +1,4 @@
-use crate::TableMeta;
+use crate::attr;
 use ormlite_core::query_builder::Placeholder;
 use proc_macro2::TokenStream;
 use quote::{quote, ToTokens};
@@ -47,8 +47,7 @@ pub trait OrmliteCodegen {
     fn placeholder() -> TokenStream;
     fn raw_placeholder() -> Placeholder;
 
-    fn impl_TableMeta(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
-        let model = &ast.ident;
+    fn impl_Model__table_meta(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let table_name = &attr.table_name;
         let id = &attr.primary_key;
         let fields = crate::util::get_fields(ast);
@@ -56,27 +55,25 @@ pub trait OrmliteCodegen {
         let n_fields = fields.len();
 
         quote! {
-            impl ::ormlite::model::TableMeta for #model {
-                fn table_name() -> &'static str {
-                    #table_name
-                }
+            fn table_name() -> &'static str {
+                #table_name
+            }
 
-                fn fields() -> &'static [&'static str] {
-                    &[#(#field_names,)*]
-                }
+            fn fields() -> &'static [&'static str] {
+                &[#(#field_names,)*]
+            }
 
-                fn num_fields() -> usize {
-                    #n_fields
-                }
+            fn num_fields() -> usize {
+                #n_fields
+            }
 
-                fn primary_key_column() -> &'static str {
-                    #id
-                }
+            fn primary_key_column() -> &'static str {
+                #id
             }
         }
     }
 
-    fn impl_Model__insert(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_Model__insert(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let box_future = crate::util::box_future();
         let db = Self::database();
         let fields = crate::util::get_fields(ast);
@@ -103,10 +100,10 @@ pub trait OrmliteCodegen {
         quote! {
             fn insert<'e, E>(self, db: E) -> #box_future<'e, ::ormlite::Result<Self>>
             where
-                E: 'e + ::ormlite::export::Executor<'e, Database = #db>,
+                E: 'e + ::ormlite::Executor<'e, Database = #db>,
             {
                 Box::pin(async move {
-                    let mut q = ::ormlite::export::query_as::<#db, Self>(#query);
+                    let mut q =::ormlite::query_as::<#db, Self>(#query);
                     #(#query_bindings)*
                     q.fetch_one(db)
                         .await
@@ -116,7 +113,7 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn impl_Model__update_all_fields(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_Model__update_all_fields(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let box_future = crate::util::box_future();
         let db = Self::database();
         let fields = crate::util::get_fields(ast);
@@ -149,10 +146,10 @@ pub trait OrmliteCodegen {
         quote! {
             fn update_all_fields<'e, E>(self, db: E) -> #box_future<'e, ::ormlite::Result<Self>>
             where
-                E: 'e + ::ormlite::export::Executor<'e, Database = #db>,
+                E: 'e +::ormlite::Executor<'e, Database = #db>,
             {
                 Box::pin(async move {
-                    let mut q = ::ormlite::export::query_as::<_, Self>(#query);
+                    let mut q =::ormlite::query_as::<_, Self>(#query);
                     #(#query_bindings)*
                     q.bind(self.#id_field)
                         .fetch_one(db)
@@ -163,7 +160,7 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn impl_Model__delete(_ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_Model__delete(_ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let mut placeholder = Self::raw_placeholder();
 
         let query = format!(
@@ -179,10 +176,10 @@ pub trait OrmliteCodegen {
         quote! {
             fn delete<'e, E>(self, db: E) -> #box_future<'e, ::ormlite::Result<()>>
             where
-                E: 'e + ::ormlite::export::Executor<'e, Database = #db>
+                E: 'e +::ormlite::Executor<'e, Database = #db>
             {
                 Box::pin(async move {
-                    let row = ::ormlite::export::query(#query)
+                    let row =::ormlite::query(#query)
                         .bind(self.#id_field)
                         .execute(db)
                         .await
@@ -197,7 +194,7 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn impl_Model__get_one(_ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_Model__get_one(_ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let mut placeholder = Self::raw_placeholder();
 
         let query = format!(
@@ -214,7 +211,7 @@ pub trait OrmliteCodegen {
             where
                 'a: 'e,
                 Arg: 'a + Send + ::sqlx::Encode<'a, #db> + ::sqlx::Type<#db>,
-                E: 'e + ::ormlite::export::Executor<'e, Database = #db>
+                E: 'e +::ormlite::Executor<'e, Database = #db>
             {
                 Box::pin(async move {
                     ::sqlx::query_as::<#db, Self>(#query)
@@ -227,46 +224,45 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn impl_Model(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_Model(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let db = Self::database();
         let model = &ast.ident;
 
-        let impl_TableMeta = Self::impl_TableMeta(ast, attr);
+        let impl_Model__table_meta = Self::impl_Model__table_meta(ast, attr);
         let impl_Model__insert = Self::impl_Model__insert(ast, attr);
         let impl_Model__update_all_fields = Self::impl_Model__update_all_fields(ast, attr);
         let impl_Model__delete = Self::impl_Model__delete(ast, attr);
         let impl_Model__get_one = Self::impl_Model__get_one(ast, attr);
+        let impl_Model__select = Self::impl_Model__select(ast, attr);
 
         quote! {
             impl ::ormlite::model::Model<#db> for #model {
+                #impl_Model__table_meta
                 #impl_Model__insert
                 #impl_Model__update_all_fields
                 #impl_Model__delete
                 #impl_Model__get_one
+                #impl_Model__select
 
                fn query(query: &str) -> ::sqlx::query::QueryAs<#db, Self, <#db as ::sqlx::database::HasArguments>::Arguments> {
                     ::sqlx::query_as::<_, Self>(query)
                 }
             }
-            #impl_TableMeta
         }
     }
 
-    fn impl_HasQueryBuilder(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_Model__select(_ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let table_name = &attr.table_name;
-        let model = &ast.ident;
         let db = Self::database();
         quote! {
-            impl ::ormlite::model::HasQueryBuilder<#db> for #model {
-                fn select<'args>() -> ::ormlite::SelectQueryBuilder<'args, #db, Self> {
-                    ::ormlite::SelectQueryBuilder::new(::ormlite::query_builder::Placeholder::question_mark())
-                        .column(&format!("\"{}\".*", #table_name))
-                }
+            fn select<'args>() -> ::ormlite::query_builder::SelectQueryBuilder<'args, #db, Self> {
+                ::ormlite::query_builder::SelectQueryBuilder::new(::ormlite::query_builder::Placeholder::question_mark())
+                    .column(&format!("\"{}\".*", #table_name))
             }
         }
     }
 
-    fn impl_HasModelBuilder(ast: &DeriveInput, _attr: &TableMeta) -> TokenStream {
+    fn impl_HasModelBuilder(ast: &DeriveInput, _attr: &attr::TableMeta) -> TokenStream {
         let model = &ast.ident;
         let partial_model = quote::format_ident!("Partial{}", model.to_string());
         quote! {
@@ -284,7 +280,7 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn struct_ModelBuilder(ast: &DeriveInput, _attr: &TableMeta) -> TokenStream {
+    fn struct_ModelBuilder(ast: &DeriveInput, _attr: &attr::TableMeta) -> TokenStream {
         let model = &ast.ident;
         let model_builder = quote::format_ident!("Partial{}", model.to_string());
         let pub_marker = &ast.vis;
@@ -361,7 +357,7 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn impl_ModelBuilder__insert(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_ModelBuilder__insert(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let box_future = crate::util::box_future();
         let db = Self::database();
         let placeholder = Self::placeholder();
@@ -376,7 +372,7 @@ pub trait OrmliteCodegen {
         quote! {
             fn insert<'e: 'a, E>(self, db: E) -> #box_future<'a, ::ormlite::Result<Self::Model>>
             where
-                E: 'e + ::ormlite::export::Executor<'e, Database = #db>,
+                E: 'e +::ormlite::Executor<'e, Database = #db>,
             {
                 Box::pin(async move {
                     let mut placeholder = #placeholder;
@@ -386,7 +382,7 @@ pub trait OrmliteCodegen {
                         set_fields.join(", "),
                         set_fields.iter().map(|_| placeholder.next().unwrap()).collect::<Vec<_>>().join(", "),
                     );
-                    let mut q = ::ormlite::export::query_as::<#db, Self::Model>(&query);
+                    let mut q =::ormlite::query_as::<#db, Self::Model>(&query);
                     #(#bind_parameters)*
                     q.fetch_one(db)
                         .await
@@ -396,7 +392,7 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn impl_ModelBuilder__update(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_ModelBuilder__update(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let fields = crate::util::get_fields(ast);
 
         let query = format!(
@@ -412,7 +408,7 @@ pub trait OrmliteCodegen {
         quote! {
             fn update<'e: 'a, E>(self, db: E) -> #box_future<'a, ::ormlite::Result<Self::Model>>
             where
-                E: 'e + ::ormlite::export::Executor<'e, Database = #db>,
+                E: 'e +::ormlite::Executor<'e, Database = #db>,
             {
                 Box::pin(async move {
                     let mut placeholder = #placeholder;
@@ -428,7 +424,7 @@ pub trait OrmliteCodegen {
                             `<model instance>.update_partial().update(&mut db)`.")
                             .#id
                     );
-                    let mut q = ::ormlite::export::query_as::<#db, Self::Model>(&query);
+                    let mut q =::ormlite::query_as::<#db, Self::Model>(&query);
                     #(#bind_update)*
                     q.fetch_one(db)
                         .await
@@ -437,7 +433,7 @@ pub trait OrmliteCodegen {
             }
         }
     }
-    fn impl_ModelBuilder(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_ModelBuilder(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let model = &ast.ident;
         let db = Self::database();
         let partial_model = quote::format_ident!("Partial{}", model.to_string());
@@ -454,7 +450,7 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn struct_InsertModel(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn struct_InsertModel(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         if attr.insert_struct.is_none() {
             return quote! {};
         }
@@ -478,7 +474,7 @@ pub trait OrmliteCodegen {
         }
     }
 
-    fn impl_InsertModel(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_InsertModel(ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         if attr.insert_struct.is_none() {
             return quote! {};
         }
@@ -518,15 +514,15 @@ pub trait OrmliteCodegen {
             });
 
         quote! {
-            impl<'a> ::ormlite::model::Insertable<'a, #db> for #insert_model {
+            impl ::ormlite::model::HasInsert<#db> for #insert_model {
                 type Model = #model;
 
-                fn insert<'e: 'a, E>(self, db: E) -> #box_future<'a, ::ormlite::Result<Self::Model>>
+                fn insert<'e, E>(self, db: E) -> #box_future<'e, ::ormlite::Result<Self::Model>>
                 where
-                    E: 'e + ::ormlite::export::Executor<'e, Database = #db>,
+                    E: 'e +::ormlite::Executor<'e, Database = #db>,
                 {
                     Box::pin(async move {
-                        let mut q = ::ormlite::export::query_as::<#db, Self::Model>(#query);
+                        let mut q =::ormlite::query_as::<#db, Self::Model>(#query);
                         #(#query_bindings)*
                         q.fetch_one(db)
                             .await
